# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdatePlace(BaseModel):
    update_place: Optional["UpdatePlaceUpdatePlace"] = Field(alias="updatePlace")


class UpdatePlaceUpdatePlace(BaseModel):
    id: str
    name: str


UpdatePlace.model_rebuild()
