# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountContents(BaseModel):
    count_contents: Optional["CountContentsCountContents"] = Field(
        alias="countContents"
    )


class CountContentsCountContents(BaseModel):
    count: Optional[Any]


CountContents.model_rebuild()
