# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteSoftware(BaseModel):
    delete_software: Optional["DeleteSoftwareDeleteSoftware"] = Field(
        alias="deleteSoftware"
    )


class DeleteSoftwareDeleteSoftware(BaseModel):
    id: str
    state: EntityState


DeleteSoftware.model_rebuild()
