# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountLabels(BaseModel):
    count_labels: Optional["CountLabelsCountLabels"] = Field(alias="countLabels")


class CountLabelsCountLabels(BaseModel):
    count: Optional[Any]


CountLabels.model_rebuild()
