# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ContentTypes, EntityState, FileTypes


class IngestUri(BaseModel):
    ingest_uri: Optional["IngestUriIngestUri"] = Field(alias="ingestUri")


class IngestUriIngestUri(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    uri: Optional[Any]
    collections: Optional[List[Optional["IngestUriIngestUriCollections"]]]


class IngestUriIngestUriCollections(BaseModel):
    id: str
    name: str


IngestUri.model_rebuild()
IngestUriIngestUri.model_rebuild()
