# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryCredits(BaseModel):
    credits: Optional[List[Optional["QueryCreditsCredits"]]]


class QueryCreditsCredits(BaseModel):
    correlation_id: Optional[str] = Field(alias="correlationId")
    owner_id: Optional[str] = Field(alias="ownerId")
    credits: Optional[Any]
    storage_ratio: Optional[Any] = Field(alias="storageRatio")
    compute_ratio: Optional[Any] = Field(alias="computeRatio")
    preparation_ratio: Optional[Any] = Field(alias="preparationRatio")
    extraction_ratio: Optional[Any] = Field(alias="extractionRatio")
    enrichment_ratio: Optional[Any] = Field(alias="enrichmentRatio")
    publishing_ratio: Optional[Any] = Field(alias="publishingRatio")
    search_ratio: Optional[Any] = Field(alias="searchRatio")
    conversation_ratio: Optional[Any] = Field(alias="conversationRatio")


QueryCredits.model_rebuild()
