# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountCollections(BaseModel):
    count_collections: Optional["CountCollectionsCountCollections"] = Field(
        alias="countCollections"
    )


class CountCollectionsCountCollections(BaseModel):
    count: Optional[Any]


CountCollections.model_rebuild()
