# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateRepo(BaseModel):
    create_repo: Optional["CreateRepoCreateRepo"] = Field(alias="createRepo")


class CreateRepoCreateRepo(BaseModel):
    id: str
    name: str


CreateRepo.model_rebuild()
