# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteContents(BaseModel):
    delete_contents: Optional[List[Optional["DeleteContentsDeleteContents"]]] = Field(
        alias="deleteContents"
    )


class DeleteContentsDeleteContents(BaseModel):
    id: str
    state: EntityState


DeleteContents.model_rebuild()
