# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllPersons(BaseModel):
    delete_all_persons: Optional[List[Optional["DeleteAllPersonsDeleteAllPersons"]]] = (
        Field(alias="deleteAllPersons")
    )


class DeleteAllPersonsDeleteAllPersons(BaseModel):
    id: str
    state: EntityState


DeleteAllPersons.model_rebuild()
